import java.io.*;

public class RandomAccessFileInputStream extends InputStream {
private RandomAccessFile raf;

public RandomAccessFileInputStream(File file) throws FileNotFoundException {
raf = new RandomAccessFile(file, "r");
}

/**
* Skip ahead in the file by the specified bytes.
*/
synchronized public void seek(long bytes) throws IOException {
raf.seek((int) bytes);
}

/**
* Skip ahead in the file by the specified bytes.
*/
synchronized public void skipForward(long bytes) throws IOException {
raf.skipBytes((int) bytes);
}

/**
* Skip backward in the file by the specified bytes.
*/
synchronized public void skipBackward(long bytes) throws IOException {
long pos = raf.getFilePointer() - bytes;

if (pos < 0)
pos = 0;

raf.seek(pos);
}

/**
* Returns the current position within the file.
*/
public long getPosition() throws IOException {
return raf.getFilePointer();
}

/**
* Returns the current position within the file as a percentage String.
*/
public String getPercentage() throws IOException {
int pos = (int) ((((float) raf.getFilePointer()) / ((float) raf
.length())) * 100);

if (pos < 10)
return "0" + pos + "%";
else
return pos + "%";

}

/**
* Returns the length of the file in bytes.
*/
public long getLength() throws IOException {
return raf.length();
}

// ----------------------------
// InputStream methods:
synchronized public int read() throws IOException {
return raf.read();
}

synchronized public int read(byte[] b) throws IOException {
return raf.read(b);
}

synchronized public int read(byte[] b, int off, int len) throws IOException {
return raf.read(b, off, len);
}

synchronized public long skip(long n) throws IOException {
long left = raf.length() - raf.getFilePointer();

if (n > left)
n = left;

return raf.skipBytes((int) n);
}

public int available() throws IOException {
return 0;
}

public void close() throws IOException {
raf.close();
}

public void mark(int readlimit) {

}

public void reset() throws IOException {

}

public boolean markSupported() {
return false;
}

}

